/*
	Render MOV Maker
	================
	version .b1

	written by Mayec Rancel


	#DESCRIPTION:
	Creates a .mov file from a render sequence. Can be used as a Post-Render script or independently.

	#NOTES:
		- You need to have Quicktime installed for this to work.
		- You also need to have the companion 'qtSeq2mov.js' script in your default scripts folder (e.g. "C:\Program Files\Autodesk\3ds Max 2010\Scripts\")

	TODO:
	- Add option to display/hide viewport elements (title, axis tripod, etc.)
	- Open Quicktime preview file after creation.
	- Save Quicktime presets in a file (to fully automatize whole process)
*/

-- start USER SETTINGS
express = false
-- end USER SETTINGS

version = ".b1"

fn renderToMov inputFile useSound:false soundFile:"" deleteFiles:false = (
	scrPath = GetDir #scripts
	print ("Executing external conversion to .MOV")
	if useSound then
		theCommand = "cscript.exe qtSeq2mov.js " + inputFile + " " + soundFile
	else
		theCommand = "cscript.exe qtSeq2mov.js " + inputFile
	DOSCommand ("cd "+scrPath + " & " + theCommand) 
)

rollout movPreviewRollout ("Render mov Maker v"+version) width:274 height:211
(	
	--rendOutputFilename
	--rendSaveFile
	button btnAbout "About"
	on btnAbout pressed do
			messagebox ("Render MOV Maker\n\n"+
				"Version: "+version+"\n\nWritten by Mayec Rancel \nhttp://www.mayec.eu\n\n"+
				"Creates a .mov file from a render sequence. Can be used as a Post-Render script or independently.\n\n"+
				"NOTE: You need to have Quicktime installed for this to work. You also need to have the companion 'qtSeq2mov.js' script in your\ndefault scripts folder (e.g. \"C:\Program Files\Autodesk\3ds Max 2010\Scripts\")")
	
	group "Render:"
	(
		editText renderFilename "filename:" text:(getFilenamePath rendOutputFilename + getFilenameFile rendOutputFilename + "*" + getFilenameType rendOutputFilename) readonly:true
	)
	
	checkbox chkDelete "Delete render sequence after .mov creation?" pos:[17,95] width:233 height:18 checked:false
	
	checkbox chkSound "Sound file:" pos:[17,129] width:73 height:18
	editText edtSoundFile "" pos:[88,127] width:138 height:22
	button btnPickSound "pick" pos:[230,129] width:39 height:19
	on btnPickSound pressed do
		edtSoundFile.text = getOpenFileName caption "pick sound file"
	
	button btnCreate "Create Quicktime!" pos:[20,167] width:105 height:31
	on btnCreate pressed do (
		-- guess precise inputFile name (filename of first render frame)
		renderFiles = getFiles renderFilename.text
		if renderFiles.count > 0 then
		(
			inputFile = renderFiles[1]
			-- execute the seq2mov converter script
			renderToMov inputFile useSound:chkSound.checked soundFile:edtSoundFile.text deleteFiles:chkDelete.checked
			
			-- if the "delete sequence" option was checked, do so
			if chkDelete.checked then
				for file in renderFiles do
					deleteFile file
				
			destroyDialog movPreviewRollout
		)
		else messageBox "Can't make .mov!\nNo render files found"
	)
	button btnCancel "Cancel" pos:[157,167] width:105 height:31
	on btnCancel pressed do
		destroyDialog movPreviewRollout
	
	on movPreviewRollout open do (
		if (WAVsound.filename != "") then
		(
			chkSound.checked = true
			edtSoundFile.text = WAVsound.filename
		)
	)
	
	on movPreviewRollout close do
		gc()
	
)

if express == false then
	createDialog movPreviewRollout
else
(
	searchString = getFilenamePath rendOutputFilename + getFilenameFile rendOutputFilename + "*" + getFilenameType rendOutputFilename
	renderFiles = getFiles searchString
	if renderFiles.count > 0 then
	(
		inputFile = renderFiles[1]
		renderToMov inputFile
	)
	else messageBox "Can't make .mov!\nNo render files found"
)